{% if value %}
    <img src="{{ STATIC_URL }}img/true.gif" title="{{ value }}" alt="{{ value }}"/>
{% else %}
    <img src="{{ STATIC_URL }}img/false.gif" title="{{ value }}" alt="{{ value }}"/>
{% endif %}