# -*- coding: utf-8 -*-
# Copyright (c) 2010-2013 by Yaco Sistemas <goinnn@gmail.com>
#               2015 by Pablo Martín <goinnn@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this programe.  If not, see <http://www.gnu.org/licenses/>.

ADAPTOR_INPLACEEDIT = {'text': 'inplaceeditform.fields.AdaptorTextField',
                       'url': 'inplaceeditform.fields.AdaptorURLField',
                       'email': 'inplaceeditform.fields.AdaptorEmailField',
                       'textarea': 'inplaceeditform.fields.AdaptorTextAreaField',
                       'choices': 'inplaceeditform.fields.AdaptorChoicesField',
                       'boolean': 'inplaceeditform.fields.AdaptorBooleanField',
                       'nullboolean': 'inplaceeditform.fields.AdaptorNullBooleanField',
                       'date': 'inplaceeditform.fields.AdaptorDateField',
                       'datetime': 'inplaceeditform.fields.AdaptorDateTimeField',
                       'time': 'inplaceeditform.fields.AdaptorTimeField',
                       'integer': 'inplaceeditform.fields.AdaptorIntegerField',
                       'float': 'inplaceeditform.fields.AdaptorFloatField',
                       'decimal': 'inplaceeditform.fields.AdaptorDecimalField',
                       'fk': 'inplaceeditform.fields.AdaptorForeingKeyField',
                       'm2m': 'inplaceeditform.fields.AdaptorManyToManyField',
                       'm2mcomma': 'inplaceeditform.fields.AdaptorCommaSeparatedManyToManyField',
                       'file': 'inplaceeditform.fields.AdaptorFileField',
                       'image': 'inplaceeditform.fields.AdaptorImageField',
                       }
