<link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/inplaceedit_structure.css" />
{% if not toolbar %}
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/inplaceedit_style.css" />
{% else %}
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/inplaceedit_toolbar_structure.css" />
    <link rel="stylesheet" type="text/css" href="{{ STATIC_URL }}css/inplaceedit_toolbar_style.css" />
{% endif %}
{{ inplace_css_extra|safe }}