.inplaceedit.enable,
.inplaceedit.enable img {
    cursor: pointer; 
}

.inplaceedit.enable {
    background: #FFFFBB;
    color: black;
}

.inplaceedit.enable img {
   border: 2px solid #FFFFBB;
}

.inplaceedit.textareainplaceedit.enable {
    display: block;
}